summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/label.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kalarm/lib/label.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/lib/label.h')
-rw-r--r--kalarm/lib/label.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/kalarm/lib/label.h b/kalarm/lib/label.h
index d5f46c4fe..bd0e39035 100644
--- a/kalarm/lib/label.h
+++ b/kalarm/lib/label.h
@@ -38,35 +38,36 @@ class LabelFocusWidget;
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class Label : public QLabel
+class Label : public TQLabel
{
Q_OBJECT
+ TQ_OBJECT
friend class LabelFocusWidget;
public:
/** Constructs an empty label.
* @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
*/
- explicit Label(TQWidget* parent, const char* name = 0, WFlags f = 0);
+ explicit Label(TQWidget* tqparent, const char* name = 0, WFlags f = 0);
/** Constructs a label that displays @p text.
* @param text Text string to display.
* @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
*/
- Label(const TQString& text, TQWidget* parent, const char* name = 0, WFlags f = 0);
+ Label(const TQString& text, TQWidget* tqparent, const char* name = 0, WFlags f = 0);
/** Constructs a label, with a buddy widget, that displays @p text.
* @param buddy Buddy widget which receives the keyboard focus when the
* label's accelerator key is pressed. If @p buddy is a radio
* button, @p buddy is in addition selected when the
* accelerator key is pressed.
* @param text Text string to display.
* @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
*/
- Label(TQWidget* buddy, const TQString& text, TQWidget* parent, const char* name = 0, WFlags f = 0);
+ Label(TQWidget* buddy, const TQString& text, TQWidget* tqparent, const char* name = 0, WFlags f = 0);
/** Sets the label's buddy widget which receives the keyboard focus when the
* label's accelerator key is pressed. If @p buddy is a radio button,
* @p buddy is in addition selected when the accelerator key is pressed.
@@ -84,11 +85,12 @@ class Label : public QLabel
// Private class for use by Label
-class LabelFocusWidget : public QWidget
+class LabelFocusWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- LabelFocusWidget(TQWidget* parent, const char* name = 0);
+ LabelFocusWidget(TQWidget* tqparent, const char* name = 0);
protected:
virtual void focusInEvent(TQFocusEvent*);
};
@@ -38,35 +38,36 @@ class LabelFocusWidget;
public:
/** Constructs an empty label.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
@@ -38,35 +38,36 @@ class LabelFocusWidget;
/** Constructs a label that displays @p text.
* @param text Text string to display.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
@@ -38,35 +38,36 @@ class LabelFocusWidget;
* accelerator key is pressed.
* @param text Text string to display.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.